Learn R Programming

survmixer (version 1.3)

scale1_taylorf: Scale parameter computation

Description

returns the value of the scale parameter in the intervention group using Taylor series

Usage

scale1_taylorf(ascale0, Delta, tau)

Arguments

ascale0

scale parameter for the weibull distribution in the control group

Delta

RMST difference between groups

tau

end of follow-up

Value

Variance computation